Crate kcr_data_fluid_io

Crate kcr_data_fluid_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the data.fluid.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

data.fluid.io/v1alpha1

  • AlluxioRuntime
  • DataBackup
  • DataLoad
  • Dataset
  • GooseFSRuntime
  • JindoRuntime
  • JuiceFSRuntime
  • ThinRuntimeProfile
  • ThinRuntime

Modules

v1alpha1